pub struct ListTopicsResponse {
pub topics: Vec<Topic>,
pub next_page_token: String,
}Expand description
Response for the ListTopics method.
Fields
topics: Vec<Topic>The resulting topics.
next_page_token: StringIf not empty, indicates that there may be more topics that match the
request; this value should be passed in a new ListTopicsRequest.